@@ -70,19 +70,28 @@ unsigned long max_array( unsigned long array[], int size )
 
 
 /* ---------------------------------------------------------------------------------------------- */
-char* format_byte_humanreadable(char* string, int stringsize, double number, int digits)
+char* format_byte_humanreadable(char* string, int stringsize, double number, int digits, gboolean as_bits)
 {
     char* str = string;
     char buffer[BUFSIZ], formatstring[BUFSIZ];
     char* bufptr = buffer;
     char* unit_names[] = { N_("B"), N_("KiB"), N_("MiB"), N_("GiB") };
-    unsigned int uidx = 1;
-    double number_displayed = number / 1024.0;
+    char* unit_names_bits[] = { N_("bps"), N_("Kbps"), N_("Mbps"), N_("Gbps") };
+    unsigned int uidx = 0;
+    double number_displayed = 0;
+    double thousand_divider = as_bits ? 1000 : 1024;
     unsigned int i;
     int numberOfIntegerChars, count;
     struct lconv* localeinfo = localeconv();
     int grouping = (int)localeinfo->grouping[0] == 0 ? INT_MAX : (int)localeinfo->grouping[0];
     
+    /* Start with kilo and adapt to bits values*/
+    uidx = 1;
+    number_displayed = number / thousand_divider;
+    if (as_bits)
+    {
+        number_displayed *= 8;
+    }
     
     /* sensible value for digits */
     if (digits < 0 || digits >= 10)
@@ -90,16 +99,16 @@ char* format_byte_humanreadable(char* string, int stringsize, double number, int
         digits = 2;
     }
     
-    /* no digits for values under MiB/s unit size */
-    if (number < 1024.0 * 1024.0)
+    /* 1 digit for values above MiB/s unit size */
+    if (digits > 1 && number_displayed > thousand_divider * thousand_divider)
     {
-        digits = 0;
+        digits = 1;
     }
 
     /* calculate number and appropriate unit size for display */
-    while(number_displayed >= 1024.0 && uidx < sizeof(unit_names))
+    while(number_displayed >= thousand_divider && uidx < (sizeof(unit_names) / sizeof(unit_names[0]) - 1))
     {
-        number_displayed /= 1024.0;
+        number_displayed /= thousand_divider;
         uidx++;
     }
 
@@ -148,7 +157,7 @@ char* format_byte_humanreadable(char* string, int stringsize, double number, int
     *str = 0;
     
     /* Add the unit name */
-    g_strlcat(string, _(unit_names[uidx]), stringsize);
+    g_strlcat(string, as_bits ? _(unit_names_bits[uidx]) : _(unit_names[uidx]), stringsize);
 
     return string;
 }
